# Package pii_optimized_logger

Configuration:

log_disable_handler
value 0 is the default value and the handler is enable
value 1 will disable the handler


log_max_length

default value is 50000
it is used to define the max length for each message to print in log